@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.77';
+our $VERSION   = '0.78';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -122,9 +122,9 @@ sub generate_accessor_method_inline {
     my $code = $self->_eval_closure(
         {},
         'sub {'
-        . $meta_instance->inline_set_slot_value('$_[0]', "'$attr_name'", '$_[1]')
+        . $meta_instance->inline_set_slot_value('$_[0]', $attr_name, '$_[1]')
         . ' if scalar(@_) == 2; '
-        . $meta_instance->inline_get_slot_value('$_[0]', "'$attr_name'")
+        . $meta_instance->inline_get_slot_value('$_[0]', $attr_name)
         . '}'
     );
     confess "Could not generate inline accessor because : $@" if $@;
@@ -138,14 +138,14 @@ sub generate_reader_method_inline {
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
-    my $code = $self->_eval_closure(
+     my $code = $self->_eval_closure(
          {},
         'sub {'
         . 'confess "Cannot assign a value to a read-only accessor" if @_ > 1;'
-        . $meta_instance->inline_get_slot_value('$_[0]', "'$attr_name'")
+        . $meta_instance->inline_get_slot_value('$_[0]', $attr_name)
         . '}'
     );
-    confess "Could not generate inline accessor because : $@" if $@;
+    confess "Could not generate inline reader because : $@" if $@;
 
     return $code;
 }
@@ -159,10 +159,10 @@ sub generate_writer_method_inline {
     my $code = $self->_eval_closure(
         {},
         'sub {'
-        . $meta_instance->inline_set_slot_value('$_[0]', "'$attr_name'", '$_[1]')
+        . $meta_instance->inline_set_slot_value('$_[0]', $attr_name, '$_[1]')
         . '}'
     );
-    confess "Could not generate inline accessor because : $@" if $@;
+    confess "Could not generate inline writer because : $@" if $@;
 
     return $code;
 }
@@ -177,7 +177,7 @@ sub generate_predicate_method_inline {
     my $code = $self->_eval_closure(
         {},
        'sub {'
-       . $meta_instance->inline_is_slot_initialized('$_[0]', "'$attr_name'")
+       . $meta_instance->inline_is_slot_initialized('$_[0]', $attr_name)
        . '}'
     );
     confess "Could not generate inline predicate because : $@" if $@;
@@ -194,7 +194,7 @@ sub generate_clearer_method_inline {
     my $code = $self->_eval_closure(
         {},
         'sub {'
-        . $meta_instance->inline_deinitialize_slot('$_[0]', "'$attr_name'")
+        . $meta_instance->inline_deinitialize_slot('$_[0]', $attr_name)
         . '}'
     );
     confess "Could not generate inline clearer because : $@" if $@;
